==> zio-aws-iot1clickdevices_2.13-5.17.127.2-sources.jar: zio/aws/iot1clickdevices/model/InvokeDeviceMethodResponse.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class InvokeDeviceMethodResponse(
    deviceMethodResponse: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.InvokeDeviceMethodResponse = {
    import InvokeDeviceMethodResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.InvokeDeviceMethodResponse
      .builder()
      .optionallyWith(
        deviceMethodResponse.map(value =>
          __string.unwrap(value): java.lang.String
        )
      )(_.deviceMethodResponse)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.InvokeDeviceMethodResponse.ReadOnly =
    zio.aws.iot1clickdevices.model.InvokeDeviceMethodResponse
      .wrap(buildAwsValue())
}
object InvokeDeviceMethodResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.InvokeDeviceMethodResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.InvokeDeviceMethodResponse =
      zio.aws.iot1clickdevices.model
        .InvokeDeviceMethodResponse(deviceMethodResponse.map(value => value))
    def deviceMethodResponse: Option[__string]
    def getDeviceMethodResponse: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("deviceMethodResponse", deviceMethodResponse)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InvokeDeviceMethodResponse
  ) extends zio.aws.iot1clickdevices.model.InvokeDeviceMethodResponse.ReadOnly {
    override val deviceMethodResponse: Option[__string] = scala
      .Option(impl.deviceMethodResponse())
      .map(value => zio.aws.iot1clickdevices.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InvokeDeviceMethodResponse
  ): zio.aws.iot1clickdevices.model.InvokeDeviceMethodResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot1clickdevices_2.13-5.17.153.2-sources.jar: zio/aws/iot1clickdevices/model/InvokeDeviceMethodResponse.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class InvokeDeviceMethodResponse(
    deviceMethodResponse: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.InvokeDeviceMethodResponse = {
    import InvokeDeviceMethodResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.InvokeDeviceMethodResponse
      .builder()
      .optionallyWith(
        deviceMethodResponse.map(value => value: java.lang.String)
      )(_.deviceMethodResponse)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.InvokeDeviceMethodResponse.ReadOnly =
    zio.aws.iot1clickdevices.model.InvokeDeviceMethodResponse
      .wrap(buildAwsValue())
}
object InvokeDeviceMethodResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.InvokeDeviceMethodResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.InvokeDeviceMethodResponse =
      zio.aws.iot1clickdevices.model
        .InvokeDeviceMethodResponse(deviceMethodResponse.map(value => value))
    def deviceMethodResponse: Option[__string]
    def getDeviceMethodResponse: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("deviceMethodResponse", deviceMethodResponse)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InvokeDeviceMethodResponse
  ) extends zio.aws.iot1clickdevices.model.InvokeDeviceMethodResponse.ReadOnly {
    override val deviceMethodResponse: Option[__string] =
      scala.Option(impl.deviceMethodResponse()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InvokeDeviceMethodResponse
  ): zio.aws.iot1clickdevices.model.InvokeDeviceMethodResponse.ReadOnly =
    new Wrapper(impl)
}
